==> funcoeszz_18.3.orig.tar.gz: funcoeszz-18.3/testador/zzdicsinonimos.sh <==
$ zzdicsinonimos certo | sed '/:$/d' | tr -d ',.' | zzhsort
bem correto direito verdadeiro 1

acertado acurado certeiro definido exato justo preciso rigoroso 2

axiomático claro efetivo garantido incontestável indiscutível indubitável inevitável infalível 3

ajustado aprovado combinado contratado determinado fixo pactuado predeterminado 4

adequado apropriado conveniente devido pertinente próprio 5

convencido convicto persuadido seguro 6

certamente certeza certo com corretamente decerto dúvida exatamente isso por positivo precisamente sem 7

algum qualquer um 8

Relacionada
certo dar
$

$ zzdicsinonimos errado | sed '/:$/d' | tr -d ',.' | zzhsort
errôneo falso imperfeito impreciso incorreto inexato inverídico 1

desacertado enganado equivocado 2

condenável impróprio inaceitável inadequado incivil inconveniente 3

desajeitado desastrado desjeitoso trapalhão 4
$

$ zzdicsinonimos bom | sed '/:$/d' | tr -d ',.' | zzhsort
bem-intencionado benevolente benévolo benfeitor benigno bondoso caridoso caritativo clemente generoso humano indulgente misericordioso piedoso 1

afável agradável aprazível deleitável encantador prazeroso 2

acertado adaptado adequado apropriado certo conveniente correto ideal próprio 3

bem-criado cortês decente delicado digno disciplinado educado gentil honesto honrado íntegro irrepreensível justo nobre obediente sério virtuoso 4

apto capaz competente eficiente expedito hábil habilitado 5

apetitoso deleitoso delicioso gostoso saboroso 6

bravo corajoso destemido impávido intrépido meritório resoluto valente 7

assegurado considerável estável favorável firme garantido grande legal lícito lucrativo propício rendoso seguro significante útil válido vantajoso 8

benéfico robusto sadio salutar são saudável 9

curado livre recuperado restabelecido sarado 10

Relacionadas
bom bom bom gosto humor senso
$

$ zzdicsinonimos mal | sed '/:$/d' | tr -d ',.' | zzhsort
defeituosamente desarmoniosamente erradamente ilegalmente inadequadamente incorretamente irregularmente 1

de deficientemente imperfeitamente incompletamente insatisfatoriamente insuficientemente leve pouco rapidamente 2

a apenas com custo desfavoravelmente dificilmente dificuldade dificultosamente negativamente penosamente 3

barbaramente bruscamente cruelmente desumanamente duramente grosseiramente impropriamente inconvenientemente indevidamente injustamente rudemente severamente 4

jamais não nunca 5

assim logo mal que que que 6

acidente adversidade azar calamidade dano desastre desdita desfortúnio desgosto desgraça desgraceira desventura estrago fatalidade infelicidade infortúnio lástima má maldição mofina perda prejuízo revés sorte tragédia tribulação 7

adoecimento distúrbio doença enfermidade mazela moléstia morbo 8

aflição angústia castigo correção dor expiação inquietação mágoa pena pesar punição sofrimento 9

defeito deficiência deformidade desvantagem eiva falha fraco fraqueza imperfeição inconveniência mácula mancha pecado problema senão vício 10

crueldade maldade malefício malevolência malfeito malignidade nocividade perniciosidade perversidade ruindade 11

Relacionadas
foi mal mal-entendido mal-estar
$

==> funcoeszz_21.1.orig.tar.gz: funcoeszz-21.1/testador/zzdicsinonimos.sh <==
$ zzdicsinonimos certo | sed '/:$/d' | tr -d ',.' | zzhsort
bem correto direito verdadeiro 1

acertado acurado certeiro definido exato justo preciso rigoroso 2

axiomático claro efetivo garantido incontestável indiscutível indubitável inevitável infalível 3

ajustado aprovado combinado contratado determinado fixo pactuado predeterminado 4

adequado apropriado conveniente devido pertinente próprio 5

convencido convicto persuadido seguro 6

certamente certeza certo com corretamente decerto dúvida exatamente isso por positivo precisamente sem 7

algum qualquer um 8

Relacionada
certo dar
$

$ zzdicsinonimos errado | sed '/:$/d' | tr -d ',.' | zzhsort
errôneo falso imperfeito impreciso incorreto inexato inverídico 1

desacertado enganado equivocado 2

condenável impróprio inaceitável inadequado incivil inconveniente 3

desajeitado desastrado desjeitoso trapalhão 4
$

$ zzdicsinonimos honesto | sed '/:$/d' | tr -d ',.' | zzhsort
bom correto decente digno direito distinto educado escrupuloso honrado íntegro probo reto 1

aberto espontâneo franco lhano natural sincero veraz verdadeiro 2

capaz consciencioso imparcial justo responsável sério 3

aceitável adequado apropriado conveniente razoável regular satisfatório 4

casto decoroso imaculado modesto pudico puro recatado virtuoso 5
$

$ zzdicsinonimos mal | sed '/:$/d' | tr -d ',.' | zzhsort
defeituosamente desarmoniosamente erradamente ilegalmente inadequadamente incorretamente irregularmente 1

de deficientemente imperfeitamente incompletamente insatisfatoriamente insuficientemente leve pouco rapidamente 2

a apenas com custo desfavoravelmente dificilmente dificuldade dificultosamente negativamente penosamente 3

barbaramente bruscamente cruelmente desumanamente duramente grosseiramente impropriamente inconvenientemente indevidamente injustamente rudemente severamente 4

jamais não nunca 5

assim logo mal que que que 6

acidente adversidade azar calamidade dano desastre desdita desfortúnio desgosto desgraça desgraceira desventura estrago fatalidade infelicidade infortúnio lástima má maldição mofina perda prejuízo revés sorte tragédia tribulação 7

adoecimento distúrbio doença enfermidade mazela moléstia morbo 8

aflição angústia castigo correção dor expiação inquietação mágoa pena pesar punição sofrimento 9

defeito deficiência deformidade desvantagem eiva falha fraco fraqueza imperfeição inconveniência mácula mancha pecado problema senão vício 10

crueldade maldade malefício malevolência malfeito malignidade nocividade perniciosidade perversidade ruindade 11

Relacionadas
foi mal mal-entendido mal-estar
$
